@@ -84,7 +84,7 @@ class DataBaseWorker:
     def __check_dialect(self):
         if self.db not in base_converter_params.keys():
             raise ModuleNotFoundError(
-                "Dialect for {} type of database was'nt found, should be in list {}".format(
+                "Dialect for {} type of database wasn't found, should be in list {}".format(
                     self.db, list(base_converter_params.keys())
                 )
             )
